@@ -1,3 +1,14 @@
+#    Copyright 2021 KeinShin
+#    Licensed under the Apache License, Version 2.0 (the "License");
+#    you may not use this file except in compliance with the License.
+#    You may obtain a copy of the License at
+#        http://www.apache.org/licenses/LICENSE-2.0
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS,
+#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#    See the License for the specific language governing permissions and
+#    limitations under the License.
+
 from bs4 import BeautifulSoup
 import requests
 import moviepy.editor  as  mp
@@ -8,11 +19,13 @@ import re
 from urllib.request import urlopen,Request
 from lxml import etree
 from requests.api import head
-
+import base
 import pytube  
 from pytube import YouTube  
 
+
 class crawl:
+    
     def __init__(self,video_name:str="",video_id:str="",output: str = "",video_link:str=''):
         self.name = video_name
         
@@ -36,17 +49,25 @@ class crawl:
         user_agent = 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7'
         headers = {'User-Agent':user_agent} 
         self.link=self.link2
+    
+    
         session = HTMLSession()
         response = session.get(self.link2)
         response.html.render(sleep=1)
         self.soup = BeautifulSoup(response.html.html, "html.parser") 
     
+    
+    
+    
+    
+    
     def keyword(self):
             
         self.title = self.soup.find("meta",attrs={"name":"keywords"})
         
         return self.title["content"]
-        
+    
+       
     def videolink(self):
         return self.vidid
     
@@ -70,7 +91,8 @@ class crawl:
          "Channel" : self.channel()
         }
         return params
-        
+    
+    
     def likes_dislikes(self):
         session = HTMLSession()
         response = session.get(self.link2)
@@ -81,26 +103,30 @@ class crawl:
             likes_dislikes.append(i.get_text())
         return likes_dislikes
     
+    
     def upload_time_and_title(self):
         det=[]
         title=self.soup.find_all("yt-formatted-string",{"class":"style-scope ytd-video-primary-info-renderer"})
         for i in title:
             det.append(i.get_text())
         return det
-
+    
     def VidTitle(self):
         return self.upload_time_and_title()[0]
 
+    
     def videoUploadTime(self):
         return self.upload_time_and_title()[1]
         
 
+    
     def description(self):
         descrip=''
         for i in self.soup.find_all("span",{"class":"style-scope yt-formatted-string"}):
             descrip+=i.get_text()
         return descrip
     
+    
     def channel(self):
         channelinfo={}
         name=self.soup.find("yt-formatted-string", {"class": "ytd-channel-name"})
@@ -115,6 +141,7 @@ class crawl:
         })
         return channelinfo
     
+    
     def download(self,to_mp3:bool=False,mp3name:str=''):
         
         if not self.out:
@@ -126,10 +153,12 @@ class crawl:
 
         yt.download(path)
                 
+    
     def veiws(self):
         veiws=self.soup.find("span",{"class":"view-count style-scope ytd-video-view-count-renderer"})
         return veiws.text
     
+    
     def videolink(self):
       ida=self.soup.find("link",{"rel":"shortlinkUrl"})
       return ida.get("href")
